PathConverter class
Responsible for converting all the different svg shapes into a path.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCircle(
XmlElement circleTag) → XmlElement -
Converts a
circleelement into apathelement. -
fromElement(
XmlElement element) → XmlElement? -
Converts any of svg's basic shapes into a
pathelement. -
fromEllipse(
XmlElement ellipseTag) → XmlElement -
Converts a
ellipseelement into apathelement. -
fromLine(
XmlElement lineTag) → XmlElement -
Converts a
lineelement into apathelement. -
fromPoly(
XmlElement polylineTag, {bool isPolyline = false}) → XmlElement -
Converts a
polygonorpolylineelement into apathelement. If converting apolyline, make sure to pass theisPolylineattribute astrue. -
fromRect(
XmlElement rectTag) → XmlElement -
Converts a
rectelement into apathelement.